@@ -14,6 +14,7 @@ import click                                            # click
 import pkg_resources                                    # setuptools
 from lxml import etree                                  # lxml
 from lxml.etree import QName, SubElement                # lxml
+import lxml.html                                        # lxml
 import requests                                         # requests
 from requests.adapters import HTTPAdapter               # requests
 from requests.packages.urllib3.util.retry import Retry  # requests
@@ -57,12 +58,24 @@ def local_to_utc(dt):
 
 
 def get_mpd_data(video_url):
-    page = get(video_url).text
-    if 'dashManifestUrl\\":\\"' in page:
-        mpd_link = page.split('dashManifestUrl\\":\\"')[-1].split('\\"')[0].replace("\/", "/")
-    elif 'dashManifestUrl":"' in page:
-        mpd_link = page.split('dashManifestUrl":"')[-1].split('"')[0].replace("\/", "/")
+    req = get(video_url)
+    with open("debug.html", "w") as f:
+        f.write(req.text)
+    if 'dashManifestUrl\\":\\"' in req.text:
+        mpd_link = req.text.split('dashManifestUrl\\":\\"')[-1].split('\\"')[0].replace("\/", "/")
+    elif 'dashManifestUrl":"' in req.text:
+        mpd_link = req.text.split('dashManifestUrl":"')[-1].split('"')[0].replace("\/", "/")
     else:
+        doc = lxml.html.fromstring(req.content)
+        form = doc.xpath('//form[@action="https://consent.youtube.com/s"]')
+        if len(form) > 0:
+            print("Consent check detected. Will try to pass...")
+            params = form[0].xpath('.//input[@type="hidden"]')
+            pars = {}
+            for par in params:
+                pars[par.attrib['name']] = par.attrib['value']
+            s.post("https://consent.youtube.com/s", data=pars)
+            return get_mpd_data(video_url)
         return None
     return get(mpd_link).text
 
